# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RecordOperation(object):
    """
    An extension of the existing record resource, describing either a
    precondition, an add, or a remove. Preconditions check all fields,
    including read-only data like `recordHash` and `rrsetVersion`.
    """

    #: A constant which can be used with the operation property of a RecordOperation.
    #: This constant has a value of "REQUIRE"
    OPERATION_REQUIRE = "REQUIRE"

    #: A constant which can be used with the operation property of a RecordOperation.
    #: This constant has a value of "PROHIBIT"
    OPERATION_PROHIBIT = "PROHIBIT"

    #: A constant which can be used with the operation property of a RecordOperation.
    #: This constant has a value of "ADD"
    OPERATION_ADD = "ADD"

    #: A constant which can be used with the operation property of a RecordOperation.
    #: This constant has a value of "REMOVE"
    OPERATION_REMOVE = "REMOVE"

    def __init__(self, **kwargs):
        """
        Initializes a new RecordOperation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param domain:
            The value to assign to the domain property of this RecordOperation.
        :type domain: str

        :param record_hash:
            The value to assign to the record_hash property of this RecordOperation.
        :type record_hash: str

        :param is_protected:
            The value to assign to the is_protected property of this RecordOperation.
        :type is_protected: bool

        :param rdata:
            The value to assign to the rdata property of this RecordOperation.
        :type rdata: str

        :param rrset_version:
            The value to assign to the rrset_version property of this RecordOperation.
        :type rrset_version: str

        :param rtype:
            The value to assign to the rtype property of this RecordOperation.
        :type rtype: str

        :param ttl:
            The value to assign to the ttl property of this RecordOperation.
        :type ttl: int

        :param operation:
            The value to assign to the operation property of this RecordOperation.
            Allowed values for this property are: "REQUIRE", "PROHIBIT", "ADD", "REMOVE"
        :type operation: str

        """
        self.swagger_types = {
            'domain': 'str',
            'record_hash': 'str',
            'is_protected': 'bool',
            'rdata': 'str',
            'rrset_version': 'str',
            'rtype': 'str',
            'ttl': 'int',
            'operation': 'str'
        }

        self.attribute_map = {
            'domain': 'domain',
            'record_hash': 'recordHash',
            'is_protected': 'isProtected',
            'rdata': 'rdata',
            'rrset_version': 'rrsetVersion',
            'rtype': 'rtype',
            'ttl': 'ttl',
            'operation': 'operation'
        }

        self._domain = None
        self._record_hash = None
        self._is_protected = None
        self._rdata = None
        self._rrset_version = None
        self._rtype = None
        self._ttl = None
        self._operation = None

    @property
    def domain(self):
        """
        Gets the domain of this RecordOperation.
        The fully qualified domain name where the record can be located.


        :return: The domain of this RecordOperation.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this RecordOperation.
        The fully qualified domain name where the record can be located.


        :param domain: The domain of this RecordOperation.
        :type: str
        """
        self._domain = domain

    @property
    def record_hash(self):
        """
        Gets the record_hash of this RecordOperation.
        A unique identifier for the record within its zone.


        :return: The record_hash of this RecordOperation.
        :rtype: str
        """
        return self._record_hash

    @record_hash.setter
    def record_hash(self, record_hash):
        """
        Sets the record_hash of this RecordOperation.
        A unique identifier for the record within its zone.


        :param record_hash: The record_hash of this RecordOperation.
        :type: str
        """
        self._record_hash = record_hash

    @property
    def is_protected(self):
        """
        Gets the is_protected of this RecordOperation.
        A Boolean flag indicating whether or not parts of the record
        are unable to be explicitly managed.


        :return: The is_protected of this RecordOperation.
        :rtype: bool
        """
        return self._is_protected

    @is_protected.setter
    def is_protected(self, is_protected):
        """
        Sets the is_protected of this RecordOperation.
        A Boolean flag indicating whether or not parts of the record
        are unable to be explicitly managed.


        :param is_protected: The is_protected of this RecordOperation.
        :type: bool
        """
        self._is_protected = is_protected

    @property
    def rdata(self):
        """
        Gets the rdata of this RecordOperation.
        The record's data, as whitespace-delimited tokens in
        type-specific presentation format. All RDATA is normalized and the
        returned presentation of your RDATA may differ from its initial input.
        For more information about RDATA, see `Supported DNS Resource Record Types`__

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :return: The rdata of this RecordOperation.
        :rtype: str
        """
        return self._rdata

    @rdata.setter
    def rdata(self, rdata):
        """
        Sets the rdata of this RecordOperation.
        The record's data, as whitespace-delimited tokens in
        type-specific presentation format. All RDATA is normalized and the
        returned presentation of your RDATA may differ from its initial input.
        For more information about RDATA, see `Supported DNS Resource Record Types`__

        __ https://docs.cloud.oracle.com/iaas/Content/DNS/Reference/supporteddnsresource.htm


        :param rdata: The rdata of this RecordOperation.
        :type: str
        """
        self._rdata = rdata

    @property
    def rrset_version(self):
        """
        Gets the rrset_version of this RecordOperation.
        The latest version of the record's zone in which its RRSet differs
        from the preceding version.


        :return: The rrset_version of this RecordOperation.
        :rtype: str
        """
        return self._rrset_version

    @rrset_version.setter
    def rrset_version(self, rrset_version):
        """
        Sets the rrset_version of this RecordOperation.
        The latest version of the record's zone in which its RRSet differs
        from the preceding version.


        :param rrset_version: The rrset_version of this RecordOperation.
        :type: str
        """
        self._rrset_version = rrset_version

    @property
    def rtype(self):
        """
        Gets the rtype of this RecordOperation.
        The type of DNS record, such as A or CNAME. For more information, see `Resource Record (RR) TYPEs`__.

        __ https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4


        :return: The rtype of this RecordOperation.
        :rtype: str
        """
        return self._rtype

    @rtype.setter
    def rtype(self, rtype):
        """
        Sets the rtype of this RecordOperation.
        The type of DNS record, such as A or CNAME. For more information, see `Resource Record (RR) TYPEs`__.

        __ https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4


        :param rtype: The rtype of this RecordOperation.
        :type: str
        """
        self._rtype = rtype

    @property
    def ttl(self):
        """
        Gets the ttl of this RecordOperation.
        The Time To Live for the record, in seconds.


        :return: The ttl of this RecordOperation.
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """
        Sets the ttl of this RecordOperation.
        The Time To Live for the record, in seconds.


        :param ttl: The ttl of this RecordOperation.
        :type: int
        """
        self._ttl = ttl

    @property
    def operation(self):
        """
        Gets the operation of this RecordOperation.
        A description of how a record relates to a PATCH operation.


        - `REQUIRE` indicates a precondition that record data **must** already exist.
        - `PROHIBIT` indicates a precondition that record data **must not** already exist.
        - `ADD` indicates that record data **must** exist after successful application.
        - `REMOVE` indicates that record data **must not** exist after successful application.


          **Note:** `ADD` and `REMOVE` operations can succeed even if
          they require no changes when applied, such as when the described
          records are already present or absent.


          **Note:** `ADD` and `REMOVE` operations can describe changes for
          more than one record.


          **Example:** `{ \"domain\": \"www.example.com\", \"rtype\": \"AAAA\", \"ttl\": 60 }`
          specifies a new TTL for every record in the www.example.com AAAA RRSet.

        Allowed values for this property are: "REQUIRE", "PROHIBIT", "ADD", "REMOVE"


        :return: The operation of this RecordOperation.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this RecordOperation.
        A description of how a record relates to a PATCH operation.


        - `REQUIRE` indicates a precondition that record data **must** already exist.
        - `PROHIBIT` indicates a precondition that record data **must not** already exist.
        - `ADD` indicates that record data **must** exist after successful application.
        - `REMOVE` indicates that record data **must not** exist after successful application.


          **Note:** `ADD` and `REMOVE` operations can succeed even if
          they require no changes when applied, such as when the described
          records are already present or absent.


          **Note:** `ADD` and `REMOVE` operations can describe changes for
          more than one record.


          **Example:** `{ \"domain\": \"www.example.com\", \"rtype\": \"AAAA\", \"ttl\": 60 }`
          specifies a new TTL for every record in the www.example.com AAAA RRSet.


        :param operation: The operation of this RecordOperation.
        :type: str
        """
        allowed_values = ["REQUIRE", "PROHIBIT", "ADD", "REMOVE"]
        if not value_allowed_none_or_none_sentinel(operation, allowed_values):
            raise ValueError(
                "Invalid value for `operation`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._operation = operation

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_data_asset_details import UpdateDataAssetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataAssetFromFusionApp(UpdateDataAssetDetails):
    """
    Details for the Autonomous Transaction Processing data asset type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataAssetFromFusionApp object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.UpdateDataAssetFromFusionApp.model_type` attribute
        of this class is ``FUSION_APP_DATA_ASSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this UpdateDataAssetFromFusionApp.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this UpdateDataAssetFromFusionApp.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this UpdateDataAssetFromFusionApp.
        :type model_version: str

        :param name:
            The value to assign to the name property of this UpdateDataAssetFromFusionApp.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateDataAssetFromFusionApp.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this UpdateDataAssetFromFusionApp.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this UpdateDataAssetFromFusionApp.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this UpdateDataAssetFromFusionApp.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this UpdateDataAssetFromFusionApp.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this UpdateDataAssetFromFusionApp.
        :type asset_properties: dict(str, str)

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateDataAssetFromFusionApp.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        :param service_url:
            The value to assign to the service_url property of this UpdateDataAssetFromFusionApp.
        :type service_url: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'registry_metadata': 'RegistryMetadata',
            'service_url': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'registry_metadata': 'registryMetadata',
            'service_url': 'serviceUrl'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._registry_metadata = None
        self._service_url = None
        self._model_type = 'FUSION_APP_DATA_ASSET'

    @property
    def service_url(self):
        """
        Gets the service_url of this UpdateDataAssetFromFusionApp.
        The service url of the BI Server.


        :return: The service_url of this UpdateDataAssetFromFusionApp.
        :rtype: str
        """
        return self._service_url

    @service_url.setter
    def service_url(self, service_url):
        """
        Sets the service_url of this UpdateDataAssetFromFusionApp.
        The service url of the BI Server.


        :param service_url: The service_url of this UpdateDataAssetFromFusionApp.
        :type: str
        """
        self._service_url = service_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ParseQueryOutput(object):
    """
    Returns a parser agnostic breakdown of a query string for client query string introspection.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ParseQueryOutput object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_query_string:
            The value to assign to the display_query_string property of this ParseQueryOutput.
        :type display_query_string: str

        :param internal_query_string:
            The value to assign to the internal_query_string property of this ParseQueryOutput.
        :type internal_query_string: str

        :param columns:
            The value to assign to the columns property of this ParseQueryOutput.
        :type columns: list[oci.log_analytics.models.AbstractColumn]

        :param response_time_in_ms:
            The value to assign to the response_time_in_ms property of this ParseQueryOutput.
        :type response_time_in_ms: int

        :param commands:
            The value to assign to the commands property of this ParseQueryOutput.
        :type commands: list[oci.log_analytics.models.AbstractCommandDescriptor]

        """
        self.swagger_types = {
            'display_query_string': 'str',
            'internal_query_string': 'str',
            'columns': 'list[AbstractColumn]',
            'response_time_in_ms': 'int',
            'commands': 'list[AbstractCommandDescriptor]'
        }

        self.attribute_map = {
            'display_query_string': 'displayQueryString',
            'internal_query_string': 'internalQueryString',
            'columns': 'columns',
            'response_time_in_ms': 'responseTimeInMs',
            'commands': 'commands'
        }

        self._display_query_string = None
        self._internal_query_string = None
        self._columns = None
        self._response_time_in_ms = None
        self._commands = None

    @property
    def display_query_string(self):
        """
        **[Required]** Gets the display_query_string of this ParseQueryOutput.
        Display string formatted by query builder of user specified query string.


        :return: The display_query_string of this ParseQueryOutput.
        :rtype: str
        """
        return self._display_query_string

    @display_query_string.setter
    def display_query_string(self, display_query_string):
        """
        Sets the display_query_string of this ParseQueryOutput.
        Display string formatted by query builder of user specified query string.


        :param display_query_string: The display_query_string of this ParseQueryOutput.
        :type: str
        """
        self._display_query_string = display_query_string

    @property
    def internal_query_string(self):
        """
        **[Required]** Gets the internal_query_string of this ParseQueryOutput.
        Internal string formatted by query builder of user specified query string.


        :return: The internal_query_string of this ParseQueryOutput.
        :rtype: str
        """
        return self._internal_query_string

    @internal_query_string.setter
    def internal_query_string(self, internal_query_string):
        """
        Sets the internal_query_string of this ParseQueryOutput.
        Internal string formatted by query builder of user specified query string.


        :param internal_query_string: The internal_query_string of this ParseQueryOutput.
        :type: str
        """
        self._internal_query_string = internal_query_string

    @property
    def columns(self):
        """
        Gets the columns of this ParseQueryOutput.
        List of columns returned by the specified query string as result output.


        :return: The columns of this ParseQueryOutput.
        :rtype: list[oci.log_analytics.models.AbstractColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this ParseQueryOutput.
        List of columns returned by the specified query string as result output.


        :param columns: The columns of this ParseQueryOutput.
        :type: list[oci.log_analytics.models.AbstractColumn]
        """
        self._columns = columns

    @property
    def response_time_in_ms(self):
        """
        Gets the response_time_in_ms of this ParseQueryOutput.
        Operation response time.


        :return: The response_time_in_ms of this ParseQueryOutput.
        :rtype: int
        """
        return self._response_time_in_ms

    @response_time_in_ms.setter
    def response_time_in_ms(self, response_time_in_ms):
        """
        Sets the response_time_in_ms of this ParseQueryOutput.
        Operation response time.


        :param response_time_in_ms: The response_time_in_ms of this ParseQueryOutput.
        :type: int
        """
        self._response_time_in_ms = response_time_in_ms

    @property
    def commands(self):
        """
        Gets the commands of this ParseQueryOutput.
        List of querylanguage command descriptors, describing the specfied query string.


        :return: The commands of this ParseQueryOutput.
        :rtype: list[oci.log_analytics.models.AbstractCommandDescriptor]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """
        Sets the commands of this ParseQueryOutput.
        List of querylanguage command descriptors, describing the specfied query string.


        :param commands: The commands of this ParseQueryOutput.
        :type: list[oci.log_analytics.models.AbstractCommandDescriptor]
        """
        self._commands = commands

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .charsetgroupprober import CharSetGroupProber
from .hebrewprober import HebrewProber
from .langbulgarianmodel import (ISO_8859_5_BULGARIAN_MODEL,
                                 WINDOWS_1251_BULGARIAN_MODEL)
from .langgreekmodel import ISO_8859_7_GREEK_MODEL, WINDOWS_1253_GREEK_MODEL
from .langhebrewmodel import WINDOWS_1255_HEBREW_MODEL
# from .langhungarianmodel import (ISO_8859_2_HUNGARIAN_MODEL,
#                                  WINDOWS_1250_HUNGARIAN_MODEL)
from .langrussianmodel import (IBM855_RUSSIAN_MODEL, IBM866_RUSSIAN_MODEL,
                               ISO_8859_5_RUSSIAN_MODEL, KOI8_R_RUSSIAN_MODEL,
                               MACCYRILLIC_RUSSIAN_MODEL,
                               WINDOWS_1251_RUSSIAN_MODEL)
from .langthaimodel import TIS_620_THAI_MODEL
from .langturkishmodel import ISO_8859_9_TURKISH_MODEL
from .sbcharsetprober import SingleByteCharSetProber


class SBCSGroupProber(CharSetGroupProber):
    def __init__(self):
        super(SBCSGroupProber, self).__init__()
        hebrew_prober = HebrewProber()
        logical_hebrew_prober = SingleByteCharSetProber(WINDOWS_1255_HEBREW_MODEL,
                                                        False, hebrew_prober)
        # TODO: See if using ISO-8859-8 Hebrew model works better here, since
        #       it's actually the visual one
        visual_hebrew_prober = SingleByteCharSetProber(WINDOWS_1255_HEBREW_MODEL,
                                                       True, hebrew_prober)
        hebrew_prober.set_model_probers(logical_hebrew_prober,
                                        visual_hebrew_prober)
        # TODO: ORDER MATTERS HERE. I changed the order vs what was in master
        #       and several tests failed that did not before. Some thought
        #       should be put into the ordering, and we should consider making
        #       order not matter here, because that is very counter-intuitive.
        self.probers = [
            SingleByteCharSetProber(WINDOWS_1251_RUSSIAN_MODEL),
            SingleByteCharSetProber(KOI8_R_RUSSIAN_MODEL),
            SingleByteCharSetProber(ISO_8859_5_RUSSIAN_MODEL),
            SingleByteCharSetProber(MACCYRILLIC_RUSSIAN_MODEL),
            SingleByteCharSetProber(IBM866_RUSSIAN_MODEL),
            SingleByteCharSetProber(IBM855_RUSSIAN_MODEL),
            SingleByteCharSetProber(ISO_8859_7_GREEK_MODEL),
            SingleByteCharSetProber(WINDOWS_1253_GREEK_MODEL),
            SingleByteCharSetProber(ISO_8859_5_BULGARIAN_MODEL),
            SingleByteCharSetProber(WINDOWS_1251_BULGARIAN_MODEL),
            # TODO: Restore Hungarian encodings (iso-8859-2 and windows-1250)
            #       after we retrain model.
            # SingleByteCharSetProber(ISO_8859_2_HUNGARIAN_MODEL),
            # SingleByteCharSetProber(WINDOWS_1250_HUNGARIAN_MODEL),
            SingleByteCharSetProber(TIS_620_THAI_MODEL),
            SingleByteCharSetProber(ISO_8859_9_TURKISH_MODEL),
            hebrew_prober,
            logical_hebrew_prober,
            visual_hebrew_prober,
        ]
        self.reset()



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsPatternFilter(object):
    """
    LogAnalyticsPatternFilter
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsPatternFilter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pattern:
            The value to assign to the pattern property of this LogAnalyticsPatternFilter.
        :type pattern: oci.log_analytics.models.LogAnalyticsSourcePattern

        :param agent_version:
            The value to assign to the agent_version property of this LogAnalyticsPatternFilter.
        :type agent_version: str

        :param is_in_use:
            The value to assign to the is_in_use property of this LogAnalyticsPatternFilter.
        :type is_in_use: bool

        :param operating_system:
            The value to assign to the operating_system property of this LogAnalyticsPatternFilter.
        :type operating_system: str

        :param pattern_id:
            The value to assign to the pattern_id property of this LogAnalyticsPatternFilter.
        :type pattern_id: int

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsPatternFilter.
        :type source_id: int

        :param version:
            The value to assign to the version property of this LogAnalyticsPatternFilter.
        :type version: str

        :param source:
            The value to assign to the source property of this LogAnalyticsPatternFilter.
        :type source: oci.log_analytics.models.LogAnalyticsSource

        """
        self.swagger_types = {
            'pattern': 'LogAnalyticsSourcePattern',
            'agent_version': 'str',
            'is_in_use': 'bool',
            'operating_system': 'str',
            'pattern_id': 'int',
            'source_id': 'int',
            'version': 'str',
            'source': 'LogAnalyticsSource'
        }

        self.attribute_map = {
            'pattern': 'pattern',
            'agent_version': 'agentVersion',
            'is_in_use': 'isInUse',
            'operating_system': 'operatingSystem',
            'pattern_id': 'patternId',
            'source_id': 'sourceId',
            'version': 'version',
            'source': 'source'
        }

        self._pattern = None
        self._agent_version = None
        self._is_in_use = None
        self._operating_system = None
        self._pattern_id = None
        self._source_id = None
        self._version = None
        self._source = None

    @property
    def pattern(self):
        """
        Gets the pattern of this LogAnalyticsPatternFilter.

        :return: The pattern of this LogAnalyticsPatternFilter.
        :rtype: oci.log_analytics.models.LogAnalyticsSourcePattern
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this LogAnalyticsPatternFilter.

        :param pattern: The pattern of this LogAnalyticsPatternFilter.
        :type: oci.log_analytics.models.LogAnalyticsSourcePattern
        """
        self._pattern = pattern

    @property
    def agent_version(self):
        """
        Gets the agent_version of this LogAnalyticsPatternFilter.
        The agent version.


        :return: The agent_version of this LogAnalyticsPatternFilter.
        :rtype: str
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """
        Sets the agent_version of this LogAnalyticsPatternFilter.
        The agent version.


        :param agent_version: The agent_version of this LogAnalyticsPatternFilter.
        :type: str
        """
        self._agent_version = agent_version

    @property
    def is_in_use(self):
        """
        Gets the is_in_use of this LogAnalyticsPatternFilter.
        A flag indicating whether or not the pattern filter is currently
        in use.


        :return: The is_in_use of this LogAnalyticsPatternFilter.
        :rtype: bool
        """
        return self._is_in_use

    @is_in_use.setter
    def is_in_use(self, is_in_use):
        """
        Sets the is_in_use of this LogAnalyticsPatternFilter.
        A flag indicating whether or not the pattern filter is currently
        in use.


        :param is_in_use: The is_in_use of this LogAnalyticsPatternFilter.
        :type: bool
        """
        self._is_in_use = is_in_use

    @property
    def operating_system(self):
        """
        Gets the operating_system of this LogAnalyticsPatternFilter.
        The operating system.


        :return: The operating_system of this LogAnalyticsPatternFilter.
        :rtype: str
        """
        return self._operating_system

    @operating_system.setter
    def operating_system(self, operating_system):
        """
        Sets the operating_system of this LogAnalyticsPatternFilter.
        The operating system.


        :param operating_system: The operating_system of this LogAnalyticsPatternFilter.
        :type: str
        """
        self._operating_system = operating_system

    @property
    def pattern_id(self):
        """
        Gets the pattern_id of this LogAnalyticsPatternFilter.
        The pattern unique identifier.


        :return: The pattern_id of this LogAnalyticsPatternFilter.
        :rtype: int
        """
        return self._pattern_id

    @pattern_id.setter
    def pattern_id(self, pattern_id):
        """
        Sets the pattern_id of this LogAnalyticsPatternFilter.
        The pattern unique identifier.


        :param pattern_id: The pattern_id of this LogAnalyticsPatternFilter.
        :type: int
        """
        self._pattern_id = pattern_id

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsPatternFilter.
        The source unique identifier.


        :return: The source_id of this LogAnalyticsPatternFilter.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsPatternFilter.
        The source unique identifier.


        :param source_id: The source_id of this LogAnalyticsPatternFilter.
        :type: int
        """
        self._source_id = source_id

    @property
    def version(self):
        """
        Gets the version of this LogAnalyticsPatternFilter.
        The pattern filter version.


        :return: The version of this LogAnalyticsPatternFilter.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this LogAnalyticsPatternFilter.
        The pattern filter version.


        :param version: The version of this LogAnalyticsPatternFilter.
        :type: str
        """
        self._version = version

    @property
    def source(self):
        """
        Gets the source of this LogAnalyticsPatternFilter.

        :return: The source of this LogAnalyticsPatternFilter.
        :rtype: oci.log_analytics.models.LogAnalyticsSource
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this LogAnalyticsPatternFilter.

        :param source: The source of this LogAnalyticsPatternFilter.
        :type: oci.log_analytics.models.LogAnalyticsSource
        """
        self._source = source

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VolumeAttachmentDetail(object):
    """
    A detail of the attached block volume.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VolumeAttachmentDetail object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param volume_attachment_id:
            The value to assign to the volume_attachment_id property of this VolumeAttachmentDetail.
        :type volume_attachment_id: str

        :param volume_size_in_gbs:
            The value to assign to the volume_size_in_gbs property of this VolumeAttachmentDetail.
        :type volume_size_in_gbs: int

        """
        self.swagger_types = {
            'volume_attachment_id': 'str',
            'volume_size_in_gbs': 'int'
        }

        self.attribute_map = {
            'volume_attachment_id': 'volumeAttachmentId',
            'volume_size_in_gbs': 'volumeSizeInGBs'
        }

        self._volume_attachment_id = None
        self._volume_size_in_gbs = None

    @property
    def volume_attachment_id(self):
        """
        **[Required]** Gets the volume_attachment_id of this VolumeAttachmentDetail.
        The OCID of the volume attachment.


        :return: The volume_attachment_id of this VolumeAttachmentDetail.
        :rtype: str
        """
        return self._volume_attachment_id

    @volume_attachment_id.setter
    def volume_attachment_id(self, volume_attachment_id):
        """
        Sets the volume_attachment_id of this VolumeAttachmentDetail.
        The OCID of the volume attachment.


        :param volume_attachment_id: The volume_attachment_id of this VolumeAttachmentDetail.
        :type: str
        """
        self._volume_attachment_id = volume_attachment_id

    @property
    def volume_size_in_gbs(self):
        """
        **[Required]** Gets the volume_size_in_gbs of this VolumeAttachmentDetail.
        The size of the volume in GBs.


        :return: The volume_size_in_gbs of this VolumeAttachmentDetail.
        :rtype: int
        """
        return self._volume_size_in_gbs

    @volume_size_in_gbs.setter
    def volume_size_in_gbs(self, volume_size_in_gbs):
        """
        Sets the volume_size_in_gbs of this VolumeAttachmentDetail.
        The size of the volume in GBs.


        :param volume_size_in_gbs: The volume_size_in_gbs of this VolumeAttachmentDetail.
        :type: int
        """
        self._volume_size_in_gbs = volume_size_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_external_database_connector_details import CreateExternalDatabaseConnectorDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateExternalMacsConnectorDetails(CreateExternalDatabaseConnectorDetails):
    """
    Details for creating a resource used to connect to an external Oracle Database using
    the `Management Agent cloud service (MACS)`__.

    __ https://docs.cloud.oracle.com/iaas/management-agents/index.html
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateExternalMacsConnectorDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.CreateExternalMacsConnectorDetails.connector_type` attribute
        of this class is ``MACS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateExternalMacsConnectorDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateExternalMacsConnectorDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateExternalMacsConnectorDetails.
        :type display_name: str

        :param connector_type:
            The value to assign to the connector_type property of this CreateExternalMacsConnectorDetails.
            Allowed values for this property are: "MACS"
        :type connector_type: str

        :param external_database_id:
            The value to assign to the external_database_id property of this CreateExternalMacsConnectorDetails.
        :type external_database_id: str

        :param connection_string:
            The value to assign to the connection_string property of this CreateExternalMacsConnectorDetails.
        :type connection_string: oci.database.models.DatabaseConnectionString

        :param connection_credentials:
            The value to assign to the connection_credentials property of this CreateExternalMacsConnectorDetails.
        :type connection_credentials: oci.database.models.DatabaseConnectionCredentials

        :param connector_agent_id:
            The value to assign to the connector_agent_id property of this CreateExternalMacsConnectorDetails.
        :type connector_agent_id: str

        """
        self.swagger_types = {
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'connector_type': 'str',
            'external_database_id': 'str',
            'connection_string': 'DatabaseConnectionString',
            'connection_credentials': 'DatabaseConnectionCredentials',
            'connector_agent_id': 'str'
        }

        self.attribute_map = {
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'connector_type': 'connectorType',
            'external_database_id': 'externalDatabaseId',
            'connection_string': 'connectionString',
            'connection_credentials': 'connectionCredentials',
            'connector_agent_id': 'connectorAgentId'
        }

        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._connector_type = None
        self._external_database_id = None
        self._connection_string = None
        self._connection_credentials = None
        self._connector_agent_id = None
        self._connector_type = 'MACS'

    @property
    def connection_string(self):
        """
        **[Required]** Gets the connection_string of this CreateExternalMacsConnectorDetails.

        :return: The connection_string of this CreateExternalMacsConnectorDetails.
        :rtype: oci.database.models.DatabaseConnectionString
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this CreateExternalMacsConnectorDetails.

        :param connection_string: The connection_string of this CreateExternalMacsConnectorDetails.
        :type: oci.database.models.DatabaseConnectionString
        """
        self._connection_string = connection_string

    @property
    def connection_credentials(self):
        """
        **[Required]** Gets the connection_credentials of this CreateExternalMacsConnectorDetails.

        :return: The connection_credentials of this CreateExternalMacsConnectorDetails.
        :rtype: oci.database.models.DatabaseConnectionCredentials
        """
        return self._connection_credentials

    @connection_credentials.setter
    def connection_credentials(self, connection_credentials):
        """
        Sets the connection_credentials of this CreateExternalMacsConnectorDetails.

        :param connection_credentials: The connection_credentials of this CreateExternalMacsConnectorDetails.
        :type: oci.database.models.DatabaseConnectionCredentials
        """
        self._connection_credentials = connection_credentials

    @property
    def connector_agent_id(self):
        """
        **[Required]** Gets the connector_agent_id of this CreateExternalMacsConnectorDetails.
        The ID of the agent used for the
        :func:`create_external_database_connector_details`.


        :return: The connector_agent_id of this CreateExternalMacsConnectorDetails.
        :rtype: str
        """
        return self._connector_agent_id

    @connector_agent_id.setter
    def connector_agent_id(self, connector_agent_id):
        """
        Sets the connector_agent_id of this CreateExternalMacsConnectorDetails.
        The ID of the agent used for the
        :func:`create_external_database_connector_details`.


        :param connector_agent_id: The connector_agent_id of this CreateExternalMacsConnectorDetails.
        :type: str
        """
        self._connector_agent_id = connector_agent_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WafConfigDetails(object):
    """
    The Web Application Firewall configuration for the WAAS policy creation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WafConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param access_rules:
            The value to assign to the access_rules property of this WafConfigDetails.
        :type access_rules: list[oci.waas.models.AccessRule]

        :param address_rate_limiting:
            The value to assign to the address_rate_limiting property of this WafConfigDetails.
        :type address_rate_limiting: oci.waas.models.AddressRateLimiting

        :param captchas:
            The value to assign to the captchas property of this WafConfigDetails.
        :type captchas: list[oci.waas.models.Captcha]

        :param device_fingerprint_challenge:
            The value to assign to the device_fingerprint_challenge property of this WafConfigDetails.
        :type device_fingerprint_challenge: oci.waas.models.DeviceFingerprintChallenge

        :param human_interaction_challenge:
            The value to assign to the human_interaction_challenge property of this WafConfigDetails.
        :type human_interaction_challenge: oci.waas.models.HumanInteractionChallenge

        :param js_challenge:
            The value to assign to the js_challenge property of this WafConfigDetails.
        :type js_challenge: oci.waas.models.JsChallenge

        :param origin:
            The value to assign to the origin property of this WafConfigDetails.
        :type origin: str

        :param caching_rules:
            The value to assign to the caching_rules property of this WafConfigDetails.
        :type caching_rules: list[oci.waas.models.CachingRule]

        :param custom_protection_rules:
            The value to assign to the custom_protection_rules property of this WafConfigDetails.
        :type custom_protection_rules: list[oci.waas.models.CustomProtectionRuleSetting]

        :param origin_groups:
            The value to assign to the origin_groups property of this WafConfigDetails.
        :type origin_groups: list[str]

        :param protection_settings:
            The value to assign to the protection_settings property of this WafConfigDetails.
        :type protection_settings: oci.waas.models.ProtectionSettings

        :param whitelists:
            The value to assign to the whitelists property of this WafConfigDetails.
        :type whitelists: list[oci.waas.models.Whitelist]

        """
        self.swagger_types = {
            'access_rules': 'list[AccessRule]',
            'address_rate_limiting': 'AddressRateLimiting',
            'captchas': 'list[Captcha]',
            'device_fingerprint_challenge': 'DeviceFingerprintChallenge',
            'human_interaction_challenge': 'HumanInteractionChallenge',
            'js_challenge': 'JsChallenge',
            'origin': 'str',
            'caching_rules': 'list[CachingRule]',
            'custom_protection_rules': 'list[CustomProtectionRuleSetting]',
            'origin_groups': 'list[str]',
            'protection_settings': 'ProtectionSettings',
            'whitelists': 'list[Whitelist]'
        }

        self.attribute_map = {
            'access_rules': 'accessRules',
            'address_rate_limiting': 'addressRateLimiting',
            'captchas': 'captchas',
            'device_fingerprint_challenge': 'deviceFingerprintChallenge',
            'human_interaction_challenge': 'humanInteractionChallenge',
            'js_challenge': 'jsChallenge',
            'origin': 'origin',
            'caching_rules': 'cachingRules',
            'custom_protection_rules': 'customProtectionRules',
            'origin_groups': 'originGroups',
            'protection_settings': 'protectionSettings',
            'whitelists': 'whitelists'
        }

        self._access_rules = None
        self._address_rate_limiting = None
        self._captchas = None
        self._device_fingerprint_challenge = None
        self._human_interaction_challenge = None
        self._js_challenge = None
        self._origin = None
        self._caching_rules = None
        self._custom_protection_rules = None
        self._origin_groups = None
        self._protection_settings = None
        self._whitelists = None

    @property
    def access_rules(self):
        """
        Gets the access_rules of this WafConfigDetails.
        The access rules applied to the Web Application Firewall. Access rules allow custom content access policies to be defined and `ALLOW`, `DETECT`, or `BLOCK` actions to be taken on a request when specified criteria are met.


        :return: The access_rules of this WafConfigDetails.
        :rtype: list[oci.waas.models.AccessRule]
        """
        return self._access_rules

    @access_rules.setter
    def access_rules(self, access_rules):
        """
        Sets the access_rules of this WafConfigDetails.
        The access rules applied to the Web Application Firewall. Access rules allow custom content access policies to be defined and `ALLOW`, `DETECT`, or `BLOCK` actions to be taken on a request when specified criteria are met.


        :param access_rules: The access_rules of this WafConfigDetails.
        :type: list[oci.waas.models.AccessRule]
        """
        self._access_rules = access_rules

    @property
    def address_rate_limiting(self):
        """
        Gets the address_rate_limiting of this WafConfigDetails.
        The settings used to limit the number of requests from an IP address.


        :return: The address_rate_limiting of this WafConfigDetails.
        :rtype: oci.waas.models.AddressRateLimiting
        """
        return self._address_rate_limiting

    @address_rate_limiting.setter
    def address_rate_limiting(self, address_rate_limiting):
        """
        Sets the address_rate_limiting of this WafConfigDetails.
        The settings used to limit the number of requests from an IP address.


        :param address_rate_limiting: The address_rate_limiting of this WafConfigDetails.
        :type: oci.waas.models.AddressRateLimiting
        """
        self._address_rate_limiting = address_rate_limiting

    @property
    def captchas(self):
        """
        Gets the captchas of this WafConfigDetails.
        A list of CAPTCHA challenge settings. CAPTCHAs challenge requests to ensure a human is attempting to reach the specified URL and not a bot.


        :return: The captchas of this WafConfigDetails.
        :rtype: list[oci.waas.models.Captcha]
        """
        return self._captchas

    @captchas.setter
    def captchas(self, captchas):
        """
        Sets the captchas of this WafConfigDetails.
        A list of CAPTCHA challenge settings. CAPTCHAs challenge requests to ensure a human is attempting to reach the specified URL and not a bot.


        :param captchas: The captchas of this WafConfigDetails.
        :type: list[oci.waas.models.Captcha]
        """
        self._captchas = captchas

    @property
    def device_fingerprint_challenge(self):
        """
        Gets the device_fingerprint_challenge of this WafConfigDetails.
        The device fingerprint challenge settings. Blocks bots based on unique device fingerprint information.


        :return: The device_fingerprint_challenge of this WafConfigDetails.
        :rtype: oci.waas.models.DeviceFingerprintChallenge
        """
        return self._device_fingerprint_challenge

    @device_fingerprint_challenge.setter
    def device_fingerprint_challenge(self, device_fingerprint_challenge):
        """
        Sets the device_fingerprint_challenge of this WafConfigDetails.
        The device fingerprint challenge settings. Blocks bots based on unique device fingerprint information.


        :param device_fingerprint_challenge: The device_fingerprint_challenge of this WafConfigDetails.
        :type: oci.waas.models.DeviceFingerprintChallenge
        """
        self._device_fingerprint_challenge = device_fingerprint_challenge

    @property
    def human_interaction_challenge(self):
        """
        Gets the human_interaction_challenge of this WafConfigDetails.
        The human interaction challenge settings. Detects natural human interactions such as mouse movements, time on site, and page scrolling to identify bots.


        :return: The human_interaction_challenge of this WafConfigDetails.
        :rtype: oci.waas.models.HumanInteractionChallenge
        """
        return self._human_interaction_challenge

    @human_interaction_challenge.setter
    def human_interaction_challenge(self, human_interaction_challenge):
        """
        Sets the human_interaction_challenge of this WafConfigDetails.
        The human interaction challenge settings. Detects natural human interactions such as mouse movements, time on site, and page scrolling to identify bots.


        :param human_interaction_challenge: The human_interaction_challenge of this WafConfigDetails.
        :type: oci.waas.models.HumanInteractionChallenge
        """
        self._human_interaction_challenge = human_interaction_challenge

    @property
    def js_challenge(self):
        """
        Gets the js_challenge of this WafConfigDetails.
        The JavaScript challenge settings. Blocks bots by challenging requests from browsers that have no JavaScript support.


        :return: The js_challenge of this WafConfigDetails.
        :rtype: oci.waas.models.JsChallenge
        """
        return self._js_challenge

    @js_challenge.setter
    def js_challenge(self, js_challenge):
        """
        Sets the js_challenge of this WafConfigDetails.
        The JavaScript challenge settings. Blocks bots by challenging requests from browsers that have no JavaScript support.


        :param js_challenge: The js_challenge of this WafConfigDetails.
        :type: oci.waas.models.JsChallenge
        """
        self._js_challenge = js_challenge

    @property
    def origin(self):
        """
        Gets the origin of this WafConfigDetails.
        The key in the map of origins referencing the origin used for the Web Application Firewall. The origin must already be included in `Origins`. Required when creating the `WafConfig` resource, but is not required upon updating the configuration.


        :return: The origin of this WafConfigDetails.
        :rtype: str
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """
        Sets the origin of this WafConfigDetails.
        The key in the map of origins referencing the origin used for the Web Application Firewall. The origin must already be included in `Origins`. Required when creating the `WafConfig` resource, but is not required upon updating the configuration.


        :param origin: The origin of this WafConfigDetails.
        :type: str
        """
        self._origin = origin

    @property
    def caching_rules(self):
        """
        Gets the caching_rules of this WafConfigDetails.
        A list of caching rules applied to the web application.


        :return: The caching_rules of this WafConfigDetails.
        :rtype: list[oci.waas.models.CachingRule]
        """
        return self._caching_rules

    @caching_rules.setter
    def caching_rules(self, caching_rules):
        """
        Sets the caching_rules of this WafConfigDetails.
        A list of caching rules applied to the web application.


        :param caching_rules: The caching_rules of this WafConfigDetails.
        :type: list[oci.waas.models.CachingRule]
        """
        self._caching_rules = caching_rules

    @property
    def custom_protection_rules(self):
        """
        Gets the custom_protection_rules of this WafConfigDetails.
        A list of the custom protection rule OCIDs and their actions.


        :return: The custom_protection_rules of this WafConfigDetails.
        :rtype: list[oci.waas.models.CustomProtectionRuleSetting]
        """
        return self._custom_protection_rules

    @custom_protection_rules.setter
    def custom_protection_rules(self, custom_protection_rules):
        """
        Sets the custom_protection_rules of this WafConfigDetails.
        A list of the custom protection rule OCIDs and their actions.


        :param custom_protection_rules: The custom_protection_rules of this WafConfigDetails.
        :type: list[oci.waas.models.CustomProtectionRuleSetting]
        """
        self._custom_protection_rules = custom_protection_rules

    @property
    def origin_groups(self):
        """
        Gets the origin_groups of this WafConfigDetails.
        The map of origin groups and their keys used to associate origins to the `wafConfig`. Origin groups allow you to apply weights to groups of origins for load balancing purposes. Origins with higher weights will receive larger proportions of client requests.
        To add additional origins to your WAAS policy, update the `origins` field of a `UpdateWaasPolicy` request.


        :return: The origin_groups of this WafConfigDetails.
        :rtype: list[str]
        """
        return self._origin_groups

    @origin_groups.setter
    def origin_groups(self, origin_groups):
        """
        Sets the origin_groups of this WafConfigDetails.
        The map of origin groups and their keys used to associate origins to the `wafConfig`. Origin groups allow you to apply weights to groups of origins for load balancing purposes. Origins with higher weights will receive larger proportions of client requests.
        To add additional origins to your WAAS policy, update the `origins` field of a `UpdateWaasPolicy` request.


        :param origin_groups: The origin_groups of this WafConfigDetails.
        :type: list[str]
        """
        self._origin_groups = origin_groups

    @property
    def protection_settings(self):
        """
        Gets the protection_settings of this WafConfigDetails.
        The settings applied to protection rules.


        :return: The protection_settings of this WafConfigDetails.
        :rtype: oci.waas.models.ProtectionSettings
        """
        return self._protection_settings

    @protection_settings.setter
    def protection_settings(self, protection_settings):
        """
        Sets the protection_settings of this WafConfigDetails.
        The settings applied to protection rules.


        :param protection_settings: The protection_settings of this WafConfigDetails.
        :type: oci.waas.models.ProtectionSettings
        """
        self._protection_settings = protection_settings

    @property
    def whitelists(self):
        """
        Gets the whitelists of this WafConfigDetails.
        A list of IP addresses that bypass the Web Application Firewall.


        :return: The whitelists of this WafConfigDetails.
        :rtype: list[oci.waas.models.Whitelist]
        """
        return self._whitelists

    @whitelists.setter
    def whitelists(self, whitelists):
        """
        Sets the whitelists of this WafConfigDetails.
        A list of IP addresses that bypass the Web Application Firewall.


        :param whitelists: The whitelists of this WafConfigDetails.
        :type: list[oci.waas.models.Whitelist]
        """
        self._whitelists = whitelists

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .schedule import Schedule
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FixedFrequencySchedule(Schedule):
    """
    Fixed frequency schedule for a scheduled task.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new FixedFrequencySchedule object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.FixedFrequencySchedule.type` attribute
        of this class is ``FIXED_FREQUENCY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this FixedFrequencySchedule.
            Allowed values for this property are: "FIXED_FREQUENCY", "CRON"
        :type type: str

        :param misfire_policy:
            The value to assign to the misfire_policy property of this FixedFrequencySchedule.
            Allowed values for this property are: "RETRY_ONCE", "RETRY_INDEFINITELY", "SKIP"
        :type misfire_policy: str

        :param time_of_first_execution:
            The value to assign to the time_of_first_execution property of this FixedFrequencySchedule.
        :type time_of_first_execution: datetime

        :param recurring_interval:
            The value to assign to the recurring_interval property of this FixedFrequencySchedule.
        :type recurring_interval: str

        :param repeat_count:
            The value to assign to the repeat_count property of this FixedFrequencySchedule.
        :type repeat_count: int

        """
        self.swagger_types = {
            'type': 'str',
            'misfire_policy': 'str',
            'time_of_first_execution': 'datetime',
            'recurring_interval': 'str',
            'repeat_count': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'misfire_policy': 'misfirePolicy',
            'time_of_first_execution': 'timeOfFirstExecution',
            'recurring_interval': 'recurringInterval',
            'repeat_count': 'repeatCount'
        }

        self._type = None
        self._misfire_policy = None
        self._time_of_first_execution = None
        self._recurring_interval = None
        self._repeat_count = None
        self._type = 'FIXED_FREQUENCY'

    @property
    def recurring_interval(self):
        """
        **[Required]** Gets the recurring_interval of this FixedFrequencySchedule.
        Recurring interval in ISO 8601 extended format as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The largest supported unit is D, e.g. P14D (not P2W).
        The value must be at least 5 minutes (PT5M) and at most 3 weeks (P21D or PT30240M).


        :return: The recurring_interval of this FixedFrequencySchedule.
        :rtype: str
        """
        return self._recurring_interval

    @recurring_interval.setter
    def recurring_interval(self, recurring_interval):
        """
        Sets the recurring_interval of this FixedFrequencySchedule.
        Recurring interval in ISO 8601 extended format as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The largest supported unit is D, e.g. P14D (not P2W).
        The value must be at least 5 minutes (PT5M) and at most 3 weeks (P21D or PT30240M).


        :param recurring_interval: The recurring_interval of this FixedFrequencySchedule.
        :type: str
        """
        self._recurring_interval = recurring_interval

    @property
    def repeat_count(self):
        """
        Gets the repeat_count of this FixedFrequencySchedule.
        Number of times (0-based) to execute until auto-stop.
        Default value -1 will execute indefinitely.
        Value 0 will execute once.


        :return: The repeat_count of this FixedFrequencySchedule.
        :rtype: int
        """
        return self._repeat_count

    @repeat_count.setter
    def repeat_count(self, repeat_count):
        """
        Sets the repeat_count of this FixedFrequencySchedule.
        Number of times (0-based) to execute until auto-stop.
        Default value -1 will execute indefinitely.
        Value 0 will execute once.


        :param repeat_count: The repeat_count of this FixedFrequencySchedule.
        :type: int
        """
        self._repeat_count = repeat_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyRange(object):
    """
    The information about key range.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new KeyRange object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this KeyRange.
        :type key: oci.data_integration.models.ShapeField

        :param range:
            The value to assign to the range property of this KeyRange.
        :type range: list[str]

        """
        self.swagger_types = {
            'key': 'ShapeField',
            'range': 'list[str]'
        }

        self.attribute_map = {
            'key': 'key',
            'range': 'range'
        }

        self._key = None
        self._range = None

    @property
    def key(self):
        """
        Gets the key of this KeyRange.

        :return: The key of this KeyRange.
        :rtype: oci.data_integration.models.ShapeField
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this KeyRange.

        :param key: The key of this KeyRange.
        :type: oci.data_integration.models.ShapeField
        """
        self._key = key

    @property
    def range(self):
        """
        Gets the range of this KeyRange.
        The key range.


        :return: The range of this KeyRange.
        :rtype: list[str]
        """
        return self._range

    @range.setter
    def range(self, range):
        """
        Sets the range of this KeyRange.
        The key range.


        :param range: The range of this KeyRange.
        :type: list[str]
        """
        self._range = range

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NodePoolOptions(object):
    """
    Options for creating or updating node pools.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NodePoolOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kubernetes_versions:
            The value to assign to the kubernetes_versions property of this NodePoolOptions.
        :type kubernetes_versions: list[str]

        :param shapes:
            The value to assign to the shapes property of this NodePoolOptions.
        :type shapes: list[str]

        :param images:
            The value to assign to the images property of this NodePoolOptions.
        :type images: list[str]

        :param sources:
            The value to assign to the sources property of this NodePoolOptions.
        :type sources: list[oci.container_engine.models.NodeSourceOption]

        """
        self.swagger_types = {
            'kubernetes_versions': 'list[str]',
            'shapes': 'list[str]',
            'images': 'list[str]',
            'sources': 'list[NodeSourceOption]'
        }

        self.attribute_map = {
            'kubernetes_versions': 'kubernetesVersions',
            'shapes': 'shapes',
            'images': 'images',
            'sources': 'sources'
        }

        self._kubernetes_versions = None
        self._shapes = None
        self._images = None
        self._sources = None

    @property
    def kubernetes_versions(self):
        """
        Gets the kubernetes_versions of this NodePoolOptions.
        Available Kubernetes versions.


        :return: The kubernetes_versions of this NodePoolOptions.
        :rtype: list[str]
        """
        return self._kubernetes_versions

    @kubernetes_versions.setter
    def kubernetes_versions(self, kubernetes_versions):
        """
        Sets the kubernetes_versions of this NodePoolOptions.
        Available Kubernetes versions.


        :param kubernetes_versions: The kubernetes_versions of this NodePoolOptions.
        :type: list[str]
        """
        self._kubernetes_versions = kubernetes_versions

    @property
    def shapes(self):
        """
        Gets the shapes of this NodePoolOptions.
        Available shapes for nodes.


        :return: The shapes of this NodePoolOptions.
        :rtype: list[str]
        """
        return self._shapes

    @shapes.setter
    def shapes(self, shapes):
        """
        Sets the shapes of this NodePoolOptions.
        Available shapes for nodes.


        :param shapes: The shapes of this NodePoolOptions.
        :type: list[str]
        """
        self._shapes = shapes

    @property
    def images(self):
        """
        Gets the images of this NodePoolOptions.
        Deprecated. See sources.
        When creating a node pool using the `CreateNodePoolDetails` object, only image names contained in this
        property can be passed to the `nodeImageName` property.


        :return: The images of this NodePoolOptions.
        :rtype: list[str]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this NodePoolOptions.
        Deprecated. See sources.
        When creating a node pool using the `CreateNodePoolDetails` object, only image names contained in this
        property can be passed to the `nodeImageName` property.


        :param images: The images of this NodePoolOptions.
        :type: list[str]
        """
        self._images = images

    @property
    def sources(self):
        """
        Gets the sources of this NodePoolOptions.
        Available source of the node.


        :return: The sources of this NodePoolOptions.
        :rtype: list[oci.container_engine.models.NodeSourceOption]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """
        Sets the sources of this NodePoolOptions.
        Available source of the node.


        :param sources: The sources of this NodePoolOptions.
        :type: list[oci.container_engine.models.NodeSourceOption]
        """
        self._sources = sources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReportQuery(object):
    """
    The request of the generated Cost Analysis report.
    """

    #: A constant which can be used with the granularity property of a ReportQuery.
    #: This constant has a value of "HOURLY"
    GRANULARITY_HOURLY = "HOURLY"

    #: A constant which can be used with the granularity property of a ReportQuery.
    #: This constant has a value of "DAILY"
    GRANULARITY_DAILY = "DAILY"

    #: A constant which can be used with the granularity property of a ReportQuery.
    #: This constant has a value of "MONTHLY"
    GRANULARITY_MONTHLY = "MONTHLY"

    #: A constant which can be used with the granularity property of a ReportQuery.
    #: This constant has a value of "TOTAL"
    GRANULARITY_TOTAL = "TOTAL"

    #: A constant which can be used with the query_type property of a ReportQuery.
    #: This constant has a value of "USAGE"
    QUERY_TYPE_USAGE = "USAGE"

    #: A constant which can be used with the query_type property of a ReportQuery.
    #: This constant has a value of "COST"
    QUERY_TYPE_COST = "COST"

    #: A constant which can be used with the query_type property of a ReportQuery.
    #: This constant has a value of "CREDIT"
    QUERY_TYPE_CREDIT = "CREDIT"

    #: A constant which can be used with the query_type property of a ReportQuery.
    #: This constant has a value of "EXPIREDCREDIT"
    QUERY_TYPE_EXPIREDCREDIT = "EXPIREDCREDIT"

    #: A constant which can be used with the query_type property of a ReportQuery.
    #: This constant has a value of "ALLCREDIT"
    QUERY_TYPE_ALLCREDIT = "ALLCREDIT"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_SEVEN_DAYS"
    DATE_RANGE_NAME_LAST_SEVEN_DAYS = "LAST_SEVEN_DAYS"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_TEN_DAYS"
    DATE_RANGE_NAME_LAST_TEN_DAYS = "LAST_TEN_DAYS"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "MTD"
    DATE_RANGE_NAME_MTD = "MTD"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_TWO_MONTHS"
    DATE_RANGE_NAME_LAST_TWO_MONTHS = "LAST_TWO_MONTHS"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_THREE_MONTHS"
    DATE_RANGE_NAME_LAST_THREE_MONTHS = "LAST_THREE_MONTHS"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "ALL"
    DATE_RANGE_NAME_ALL = "ALL"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_SIX_MONTHS"
    DATE_RANGE_NAME_LAST_SIX_MONTHS = "LAST_SIX_MONTHS"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "LAST_ONE_YEAR"
    DATE_RANGE_NAME_LAST_ONE_YEAR = "LAST_ONE_YEAR"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "YTD"
    DATE_RANGE_NAME_YTD = "YTD"

    #: A constant which can be used with the date_range_name property of a ReportQuery.
    #: This constant has a value of "CUSTOM"
    DATE_RANGE_NAME_CUSTOM = "CUSTOM"

    def __init__(self, **kwargs):
        """
        Initializes a new ReportQuery object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenant_id:
            The value to assign to the tenant_id property of this ReportQuery.
        :type tenant_id: str

        :param time_usage_started:
            The value to assign to the time_usage_started property of this ReportQuery.
        :type time_usage_started: datetime

        :param time_usage_ended:
            The value to assign to the time_usage_ended property of this ReportQuery.
        :type time_usage_ended: datetime

        :param granularity:
            The value to assign to the granularity property of this ReportQuery.
            Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY", "TOTAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type granularity: str

        :param is_aggregate_by_time:
            The value to assign to the is_aggregate_by_time property of this ReportQuery.
        :type is_aggregate_by_time: bool

        :param forecast:
            The value to assign to the forecast property of this ReportQuery.
        :type forecast: oci.usage_api.models.Forecast

        :param query_type:
            The value to assign to the query_type property of this ReportQuery.
            Allowed values for this property are: "USAGE", "COST", "CREDIT", "EXPIREDCREDIT", "ALLCREDIT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type query_type: str

        :param group_by:
            The value to assign to the group_by property of this ReportQuery.
        :type group_by: list[str]

        :param group_by_tag:
            The value to assign to the group_by_tag property of this ReportQuery.
        :type group_by_tag: list[oci.usage_api.models.Tag]

        :param compartment_depth:
            The value to assign to the compartment_depth property of this ReportQuery.
        :type compartment_depth: float

        :param filter:
            The value to assign to the filter property of this ReportQuery.
        :type filter: oci.usage_api.models.Filter

        :param date_range_name:
            The value to assign to the date_range_name property of this ReportQuery.
            Allowed values for this property are: "LAST_SEVEN_DAYS", "LAST_TEN_DAYS", "MTD", "LAST_TWO_MONTHS", "LAST_THREE_MONTHS", "ALL", "LAST_SIX_MONTHS", "LAST_ONE_YEAR", "YTD", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type date_range_name: str

        """
        self.swagger_types = {
            'tenant_id': 'str',
            'time_usage_started': 'datetime',
            'time_usage_ended': 'datetime',
            'granularity': 'str',
            'is_aggregate_by_time': 'bool',
            'forecast': 'Forecast',
            'query_type': 'str',
            'group_by': 'list[str]',
            'group_by_tag': 'list[Tag]',
            'compartment_depth': 'float',
            'filter': 'Filter',
            'date_range_name': 'str'
        }

        self.attribute_map = {
            'tenant_id': 'tenantId',
            'time_usage_started': 'timeUsageStarted',
            'time_usage_ended': 'timeUsageEnded',
            'granularity': 'granularity',
            'is_aggregate_by_time': 'isAggregateByTime',
            'forecast': 'forecast',
            'query_type': 'queryType',
            'group_by': 'groupBy',
            'group_by_tag': 'groupByTag',
            'compartment_depth': 'compartmentDepth',
            'filter': 'filter',
            'date_range_name': 'dateRangeName'
        }

        self._tenant_id = None
        self._time_usage_started = None
        self._time_usage_ended = None
        self._granularity = None
        self._is_aggregate_by_time = None
        self._forecast = None
        self._query_type = None
        self._group_by = None
        self._group_by_tag = None
        self._compartment_depth = None
        self._filter = None
        self._date_range_name = None

    @property
    def tenant_id(self):
        """
        **[Required]** Gets the tenant_id of this ReportQuery.
        Tenant ID.


        :return: The tenant_id of this ReportQuery.
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """
        Sets the tenant_id of this ReportQuery.
        Tenant ID.


        :param tenant_id: The tenant_id of this ReportQuery.
        :type: str
        """
        self._tenant_id = tenant_id

    @property
    def time_usage_started(self):
        """
        Gets the time_usage_started of this ReportQuery.
        The usage start time.


        :return: The time_usage_started of this ReportQuery.
        :rtype: datetime
        """
        return self._time_usage_started

    @time_usage_started.setter
    def time_usage_started(self, time_usage_started):
        """
        Sets the time_usage_started of this ReportQuery.
        The usage start time.


        :param time_usage_started: The time_usage_started of this ReportQuery.
        :type: datetime
        """
        self._time_usage_started = time_usage_started

    @property
    def time_usage_ended(self):
        """
        Gets the time_usage_ended of this ReportQuery.
        The usage end time.


        :return: The time_usage_ended of this ReportQuery.
        :rtype: datetime
        """
        return self._time_usage_ended

    @time_usage_ended.setter
    def time_usage_ended(self, time_usage_ended):
        """
        Sets the time_usage_ended of this ReportQuery.
        The usage end time.


        :param time_usage_ended: The time_usage_ended of this ReportQuery.
        :type: datetime
        """
        self._time_usage_ended = time_usage_ended

    @property
    def granularity(self):
        """
        **[Required]** Gets the granularity of this ReportQuery.
        The usage granularity.
        HOURLY - Hourly data aggregation.
        DAILY - Daily data aggregation.
        MONTHLY - Monthly data aggregation.
        TOTAL - Not yet supported.

        Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY", "TOTAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The granularity of this ReportQuery.
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this ReportQuery.
        The usage granularity.
        HOURLY - Hourly data aggregation.
        DAILY - Daily data aggregation.
        MONTHLY - Monthly data aggregation.
        TOTAL - Not yet supported.


        :param granularity: The granularity of this ReportQuery.
        :type: str
        """
        allowed_values = ["HOURLY", "DAILY", "MONTHLY", "TOTAL"]
        if not value_allowed_none_or_none_sentinel(granularity, allowed_values):
            granularity = 'UNKNOWN_ENUM_VALUE'
        self._granularity = granularity

    @property
    def is_aggregate_by_time(self):
        """
        Gets the is_aggregate_by_time of this ReportQuery.
        Whether aggregated by time. If isAggregateByTime is true, all usage/cost over the query time period will be added up.


        :return: The is_aggregate_by_time of this ReportQuery.
        :rtype: bool
        """
        return self._is_aggregate_by_time

    @is_aggregate_by_time.setter
    def is_aggregate_by_time(self, is_aggregate_by_time):
        """
        Sets the is_aggregate_by_time of this ReportQuery.
        Whether aggregated by time. If isAggregateByTime is true, all usage/cost over the query time period will be added up.


        :param is_aggregate_by_time: The is_aggregate_by_time of this ReportQuery.
        :type: bool
        """
        self._is_aggregate_by_time = is_aggregate_by_time

    @property
    def forecast(self):
        """
        Gets the forecast of this ReportQuery.

        :return: The forecast of this ReportQuery.
        :rtype: oci.usage_api.models.Forecast
        """
        return self._forecast

    @forecast.setter
    def forecast(self, forecast):
        """
        Sets the forecast of this ReportQuery.

        :param forecast: The forecast of this ReportQuery.
        :type: oci.usage_api.models.Forecast
        """
        self._forecast = forecast

    @property
    def query_type(self):
        """
        Gets the query_type of this ReportQuery.
        The query usage type. COST by default if it is missing.
        Usage - Query the usage data.
        Cost - Query the cost/billing data.
        Credit - Query the credit adjustments data.
        ExpiredCredit - Query the expired credits data
        AllCredit - Query the credit adjustments and expired credit

        Allowed values for this property are: "USAGE", "COST", "CREDIT", "EXPIREDCREDIT", "ALLCREDIT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The query_type of this ReportQuery.
        :rtype: str
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """
        Sets the query_type of this ReportQuery.
        The query usage type. COST by default if it is missing.
        Usage - Query the usage data.
        Cost - Query the cost/billing data.
        Credit - Query the credit adjustments data.
        ExpiredCredit - Query the expired credits data
        AllCredit - Query the credit adjustments and expired credit


        :param query_type: The query_type of this ReportQuery.
        :type: str
        """
        allowed_values = ["USAGE", "COST", "CREDIT", "EXPIREDCREDIT", "ALLCREDIT"]
        if not value_allowed_none_or_none_sentinel(query_type, allowed_values):
            query_type = 'UNKNOWN_ENUM_VALUE'
        self._query_type = query_type

    @property
    def group_by(self):
        """
        Gets the group_by of this ReportQuery.
        Aggregate the result by.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :return: The group_by of this ReportQuery.
        :rtype: list[str]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this ReportQuery.
        Aggregate the result by.
        example:
          `[\"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\",
            \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\",
            \"resourceId\", \"tenantId\", \"tenantName\"]`


        :param group_by: The group_by of this ReportQuery.
        :type: list[str]
        """
        self._group_by = group_by

    @property
    def group_by_tag(self):
        """
        Gets the group_by_tag of this ReportQuery.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list.
        For example:
          `[{\"namespace\":\"oracle\", \"key\":\"createdBy\"]`


        :return: The group_by_tag of this ReportQuery.
        :rtype: list[oci.usage_api.models.Tag]
        """
        return self._group_by_tag

    @group_by_tag.setter
    def group_by_tag(self, group_by_tag):
        """
        Sets the group_by_tag of this ReportQuery.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list.
        For example:
          `[{\"namespace\":\"oracle\", \"key\":\"createdBy\"]`


        :param group_by_tag: The group_by_tag of this ReportQuery.
        :type: list[oci.usage_api.models.Tag]
        """
        self._group_by_tag = group_by_tag

    @property
    def compartment_depth(self):
        """
        Gets the compartment_depth of this ReportQuery.
        The compartment depth level.


        :return: The compartment_depth of this ReportQuery.
        :rtype: float
        """
        return self._compartment_depth

    @compartment_depth.setter
    def compartment_depth(self, compartment_depth):
        """
        Sets the compartment_depth of this ReportQuery.
        The compartment depth level.


        :param compartment_depth: The compartment_depth of this ReportQuery.
        :type: float
        """
        self._compartment_depth = compartment_depth

    @property
    def filter(self):
        """
        Gets the filter of this ReportQuery.

        :return: The filter of this ReportQuery.
        :rtype: oci.usage_api.models.Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this ReportQuery.

        :param filter: The filter of this ReportQuery.
        :type: oci.usage_api.models.Filter
        """
        self._filter = filter

    @property
    def date_range_name(self):
        """
        Gets the date_range_name of this ReportQuery.
        The UI date range, for example, LAST_THREE_MONTHS. Conflicts with timeUsageStarted and timeUsageEnded.

        Allowed values for this property are: "LAST_SEVEN_DAYS", "LAST_TEN_DAYS", "MTD", "LAST_TWO_MONTHS", "LAST_THREE_MONTHS", "ALL", "LAST_SIX_MONTHS", "LAST_ONE_YEAR", "YTD", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The date_range_name of this ReportQuery.
        :rtype: str
        """
        return self._date_range_name

    @date_range_name.setter
    def date_range_name(self, date_range_name):
        """
        Sets the date_range_name of this ReportQuery.
        The UI date range, for example, LAST_THREE_MONTHS. Conflicts with timeUsageStarted and timeUsageEnded.


        :param date_range_name: The date_range_name of this ReportQuery.
        :type: str
        """
        allowed_values = ["LAST_SEVEN_DAYS", "LAST_TEN_DAYS", "MTD", "LAST_TWO_MONTHS", "LAST_THREE_MONTHS", "ALL", "LAST_SIX_MONTHS", "LAST_ONE_YEAR", "YTD", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(date_range_name, allowed_values):
            date_range_name = 'UNKNOWN_ENUM_VALUE'
        self._date_range_name = date_range_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ListenerSummary(object):
    """
    The configuration of the listener.
    For more information about backend set configuration, see
    `Managing Load Balancer Listeners`__.

    __ https://docs.cloud.oracle.com/Content/Balance/Tasks/managinglisteners.htm
    """

    #: A constant which can be used with the protocol property of a ListenerSummary.
    #: This constant has a value of "ANY"
    PROTOCOL_ANY = "ANY"

    #: A constant which can be used with the protocol property of a ListenerSummary.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    #: A constant which can be used with the protocol property of a ListenerSummary.
    #: This constant has a value of "UDP"
    PROTOCOL_UDP = "UDP"

    def __init__(self, **kwargs):
        """
        Initializes a new ListenerSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ListenerSummary.
        :type name: str

        :param default_backend_set_name:
            The value to assign to the default_backend_set_name property of this ListenerSummary.
        :type default_backend_set_name: str

        :param port:
            The value to assign to the port property of this ListenerSummary.
        :type port: int

        :param protocol:
            The value to assign to the protocol property of this ListenerSummary.
            Allowed values for this property are: "ANY", "TCP", "UDP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        """
        self.swagger_types = {
            'name': 'str',
            'default_backend_set_name': 'str',
            'port': 'int',
            'protocol': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'default_backend_set_name': 'defaultBackendSetName',
            'port': 'port',
            'protocol': 'protocol'
        }

        self._name = None
        self._default_backend_set_name = None
        self._port = None
        self._protocol = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ListenerSummary.
        A friendly name for the listener. It must be unique and it cannot be changed.

        Example: `example_listener`


        :return: The name of this ListenerSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ListenerSummary.
        A friendly name for the listener. It must be unique and it cannot be changed.

        Example: `example_listener`


        :param name: The name of this ListenerSummary.
        :type: str
        """
        self._name = name

    @property
    def default_backend_set_name(self):
        """
        **[Required]** Gets the default_backend_set_name of this ListenerSummary.
        The name of the associated backend set.

        Example: `example_backend_set`


        :return: The default_backend_set_name of this ListenerSummary.
        :rtype: str
        """
        return self._default_backend_set_name

    @default_backend_set_name.setter
    def default_backend_set_name(self, default_backend_set_name):
        """
        Sets the default_backend_set_name of this ListenerSummary.
        The name of the associated backend set.

        Example: `example_backend_set`


        :param default_backend_set_name: The default_backend_set_name of this ListenerSummary.
        :type: str
        """
        self._default_backend_set_name = default_backend_set_name

    @property
    def port(self):
        """
        **[Required]** Gets the port of this ListenerSummary.
        The communication port for the listener.

        Example: `80`


        :return: The port of this ListenerSummary.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this ListenerSummary.
        The communication port for the listener.

        Example: `80`


        :param port: The port of this ListenerSummary.
        :type: int
        """
        self._port = port

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this ListenerSummary.
        The protocol on which the listener accepts connection requests.
        For public network load balancers, ANY protocol refers to TCP/UDP.
        For private network load balancers, ANY protocol refers to TCP/UDP/ICMP (note that ICMP requires isPreserveSourceDestination to be set to true).
        To get a list of valid protocols, use the :func:`list_network_load_balancers_protocols`
        operation.

        Example: `TCP`

        Allowed values for this property are: "ANY", "TCP", "UDP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this ListenerSummary.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this ListenerSummary.
        The protocol on which the listener accepts connection requests.
        For public network load balancers, ANY protocol refers to TCP/UDP.
        For private network load balancers, ANY protocol refers to TCP/UDP/ICMP (note that ICMP requires isPreserveSourceDestination to be set to true).
        To get a list of valid protocols, use the :func:`list_network_load_balancers_protocols`
        operation.

        Example: `TCP`


        :param protocol: The protocol of this ListenerSummary.
        :type: str
        """
        allowed_values = ["ANY", "TCP", "UDP"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchResult(object):
    """
    The search result object is the definition of an element that is returned as part of search. It contains basic
    information about the object such as key, name and description. The search result also contains the list of tags
    for each object along with other contextual information like the data asset root, folder, or entity parents.
    """

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a SearchResult.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new SearchResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this SearchResult.
        :type key: str

        :param name:
            The value to assign to the name property of this SearchResult.
        :type name: str

        :param description:
            The value to assign to the description property of this SearchResult.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this SearchResult.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SearchResult.
        :type time_updated: datetime

        :param tag_summary:
            The value to assign to the tag_summary property of this SearchResult.
        :type tag_summary: list[oci.data_catalog.models.SearchTagSummary]

        :param term_summary:
            The value to assign to the term_summary property of this SearchResult.
        :type term_summary: list[oci.data_catalog.models.SearchTermSummary]

        :param type_name:
            The value to assign to the type_name property of this SearchResult.
        :type type_name: str

        :param external_type_name:
            The value to assign to the external_type_name property of this SearchResult.
        :type external_type_name: str

        :param external_data_type:
            The value to assign to the external_data_type property of this SearchResult.
        :type external_data_type: str

        :param data_asset_key:
            The value to assign to the data_asset_key property of this SearchResult.
        :type data_asset_key: str

        :param data_asset_type:
            The value to assign to the data_asset_type property of this SearchResult.
        :type data_asset_type: str

        :param data_asset_name:
            The value to assign to the data_asset_name property of this SearchResult.
        :type data_asset_name: str

        :param folder_key:
            The value to assign to the folder_key property of this SearchResult.
        :type folder_key: str

        :param folder_type:
            The value to assign to the folder_type property of this SearchResult.
        :type folder_type: str

        :param folder_name:
            The value to assign to the folder_name property of this SearchResult.
        :type folder_name: str

        :param entitykey:
            The value to assign to the entitykey property of this SearchResult.
        :type entitykey: str

        :param entity_type:
            The value to assign to the entity_type property of this SearchResult.
        :type entity_type: str

        :param entity_name:
            The value to assign to the entity_name property of this SearchResult.
        :type entity_name: str

        :param glossary_key:
            The value to assign to the glossary_key property of this SearchResult.
        :type glossary_key: str

        :param glossary_name:
            The value to assign to the glossary_name property of this SearchResult.
        :type glossary_name: str

        :param parent_term_key:
            The value to assign to the parent_term_key property of this SearchResult.
        :type parent_term_key: str

        :param parent_term_name:
            The value to assign to the parent_term_name property of this SearchResult.
        :type parent_term_name: str

        :param created_by_id:
            The value to assign to the created_by_id property of this SearchResult.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this SearchResult.
        :type updated_by_id: str

        :param path:
            The value to assign to the path property of this SearchResult.
        :type path: str

        :param business_name:
            The value to assign to the business_name property of this SearchResult.
        :type business_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SearchResult.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param attribute_type:
            The value to assign to the attribute_type property of this SearchResult.
        :type attribute_type: str

        :param expression:
            The value to assign to the expression property of this SearchResult.
        :type expression: str

        :param custom_properties:
            The value to assign to the custom_properties property of this SearchResult.
        :type custom_properties: list[oci.data_catalog.models.FacetedSearchCustomProperty]

        """
        self.swagger_types = {
            'key': 'str',
            'name': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'tag_summary': 'list[SearchTagSummary]',
            'term_summary': 'list[SearchTermSummary]',
            'type_name': 'str',
            'external_type_name': 'str',
            'external_data_type': 'str',
            'data_asset_key': 'str',
            'data_asset_type': 'str',
            'data_asset_name': 'str',
            'folder_key': 'str',
            'folder_type': 'str',
            'folder_name': 'str',
            'entitykey': 'str',
            'entity_type': 'str',
            'entity_name': 'str',
            'glossary_key': 'str',
            'glossary_name': 'str',
            'parent_term_key': 'str',
            'parent_term_name': 'str',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'path': 'str',
            'business_name': 'str',
            'lifecycle_state': 'str',
            'attribute_type': 'str',
            'expression': 'str',
            'custom_properties': 'list[FacetedSearchCustomProperty]'
        }

        self.attribute_map = {
            'key': 'key',
            'name': 'name',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'tag_summary': 'tagSummary',
            'term_summary': 'termSummary',
            'type_name': 'typeName',
            'external_type_name': 'externalTypeName',
            'external_data_type': 'externalDataType',
            'data_asset_key': 'dataAssetKey',
            'data_asset_type': 'dataAssetType',
            'data_asset_name': 'dataAssetName',
            'folder_key': 'folderKey',
            'folder_type': 'folderType',
            'folder_name': 'folderName',
            'entitykey': 'entitykey',
            'entity_type': 'entityType',
            'entity_name': 'entityName',
            'glossary_key': 'glossaryKey',
            'glossary_name': 'glossaryName',
            'parent_term_key': 'parentTermKey',
            'parent_term_name': 'parentTermName',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'path': 'path',
            'business_name': 'businessName',
            'lifecycle_state': 'lifecycleState',
            'attribute_type': 'attributeType',
            'expression': 'expression',
            'custom_properties': 'customProperties'
        }

        self._key = None
        self._name = None
        self._description = None
        self._time_created = None
        self._time_updated = None
        self._tag_summary = None
        self._term_summary = None
        self._type_name = None
        self._external_type_name = None
        self._external_data_type = None
        self._data_asset_key = None
        self._data_asset_type = None
        self._data_asset_name = None
        self._folder_key = None
        self._folder_type = None
        self._folder_name = None
        self._entitykey = None
        self._entity_type = None
        self._entity_name = None
        self._glossary_key = None
        self._glossary_name = None
        self._parent_term_key = None
        self._parent_term_name = None
        self._created_by_id = None
        self._updated_by_id = None
        self._path = None
        self._business_name = None
        self._lifecycle_state = None
        self._attribute_type = None
        self._expression = None
        self._custom_properties = None

    @property
    def key(self):
        """
        Gets the key of this SearchResult.
        Unique key of the object returned as part of the search result.


        :return: The key of this SearchResult.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SearchResult.
        Unique key of the object returned as part of the search result.


        :param key: The key of this SearchResult.
        :type: str
        """
        self._key = key

    @property
    def name(self):
        """
        Gets the name of this SearchResult.
        Name of the object.


        :return: The name of this SearchResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SearchResult.
        Name of the object.


        :param name: The name of this SearchResult.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this SearchResult.
        Detailed description of the object.


        :return: The description of this SearchResult.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SearchResult.
        Detailed description of the object.


        :param description: The description of this SearchResult.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this SearchResult.
        The date and time the result object was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SearchResult.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SearchResult.
        The date and time the result object was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SearchResult.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this SearchResult.
        The date and time the result object was updated, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this SearchResult.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SearchResult.
        The date and time the result object was updated, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this SearchResult.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def tag_summary(self):
        """
        Gets the tag_summary of this SearchResult.
        Array of the tags associated with this object.


        :return: The tag_summary of this SearchResult.
        :rtype: list[oci.data_catalog.models.SearchTagSummary]
        """
        return self._tag_summary

    @tag_summary.setter
    def tag_summary(self, tag_summary):
        """
        Sets the tag_summary of this SearchResult.
        Array of the tags associated with this object.


        :param tag_summary: The tag_summary of this SearchResult.
        :type: list[oci.data_catalog.models.SearchTagSummary]
        """
        self._tag_summary = tag_summary

    @property
    def term_summary(self):
        """
        Gets the term_summary of this SearchResult.
        Array of the terms associated with this object.


        :return: The term_summary of this SearchResult.
        :rtype: list[oci.data_catalog.models.SearchTermSummary]
        """
        return self._term_summary

    @term_summary.setter
    def term_summary(self, term_summary):
        """
        Sets the term_summary of this SearchResult.
        Array of the terms associated with this object.


        :param term_summary: The term_summary of this SearchResult.
        :type: list[oci.data_catalog.models.SearchTermSummary]
        """
        self._term_summary = term_summary

    @property
    def type_name(self):
        """
        Gets the type_name of this SearchResult.
        Name of the object type.


        :return: The type_name of this SearchResult.
        :rtype: str
        """
        return self._type_name

    @type_name.setter
    def type_name(self, type_name):
        """
        Sets the type_name of this SearchResult.
        Name of the object type.


        :param type_name: The type_name of this SearchResult.
        :type: str
        """
        self._type_name = type_name

    @property
    def external_type_name(self):
        """
        Gets the external_type_name of this SearchResult.
        Name of the external object type in the host data asset. For example, column, field, table, view, or file.


        :return: The external_type_name of this SearchResult.
        :rtype: str
        """
        return self._external_type_name

    @external_type_name.setter
    def external_type_name(self, external_type_name):
        """
        Sets the external_type_name of this SearchResult.
        Name of the external object type in the host data asset. For example, column, field, table, view, or file.


        :param external_type_name: The external_type_name of this SearchResult.
        :type: str
        """
        self._external_type_name = external_type_name

    @property
    def external_data_type(self):
        """
        Gets the external_data_type of this SearchResult.
        Data type of the object if the object is an attribute. Null otherwise.


        :return: The external_data_type of this SearchResult.
        :rtype: str
        """
        return self._external_data_type

    @external_data_type.setter
    def external_data_type(self, external_data_type):
        """
        Sets the external_data_type of this SearchResult.
        Data type of the object if the object is an attribute. Null otherwise.


        :param external_data_type: The external_data_type of this SearchResult.
        :type: str
        """
        self._external_data_type = external_data_type

    @property
    def data_asset_key(self):
        """
        Gets the data_asset_key of this SearchResult.
        Unique key of the data asset that is the root parent of this object.


        :return: The data_asset_key of this SearchResult.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this SearchResult.
        Unique key of the data asset that is the root parent of this object.


        :param data_asset_key: The data_asset_key of this SearchResult.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def data_asset_type(self):
        """
        Gets the data_asset_type of this SearchResult.
        Type name of the data asset. For example, Oracle, MySQL or Oracle Object Storage.


        :return: The data_asset_type of this SearchResult.
        :rtype: str
        """
        return self._data_asset_type

    @data_asset_type.setter
    def data_asset_type(self, data_asset_type):
        """
        Sets the data_asset_type of this SearchResult.
        Type name of the data asset. For example, Oracle, MySQL or Oracle Object Storage.


        :param data_asset_type: The data_asset_type of this SearchResult.
        :type: str
        """
        self._data_asset_type = data_asset_type

    @property
    def data_asset_name(self):
        """
        Gets the data_asset_name of this SearchResult.
        Name of the data asset that is the root parent of this object.


        :return: The data_asset_name of this SearchResult.
        :rtype: str
        """
        return self._data_asset_name

    @data_asset_name.setter
    def data_asset_name(self, data_asset_name):
        """
        Sets the data_asset_name of this SearchResult.
        Name of the data asset that is the root parent of this object.


        :param data_asset_name: The data_asset_name of this SearchResult.
        :type: str
        """
        self._data_asset_name = data_asset_name

    @property
    def folder_key(self):
        """
        Gets the folder_key of this SearchResult.
        Unique key of the folder object if this object is a sub folder, entity, or attribute.


        :return: The folder_key of this SearchResult.
        :rtype: str
        """
        return self._folder_key

    @folder_key.setter
    def folder_key(self, folder_key):
        """
        Sets the folder_key of this SearchResult.
        Unique key of the folder object if this object is a sub folder, entity, or attribute.


        :param folder_key: The folder_key of this SearchResult.
        :type: str
        """
        self._folder_key = folder_key

    @property
    def folder_type(self):
        """
        Gets the folder_type of this SearchResult.
        Type name of the folder. For example, schema, directory, or topic.


        :return: The folder_type of this SearchResult.
        :rtype: str
        """
        return self._folder_type

    @folder_type.setter
    def folder_type(self, folder_type):
        """
        Sets the folder_type of this SearchResult.
        Type name of the folder. For example, schema, directory, or topic.


        :param folder_type: The folder_type of this SearchResult.
        :type: str
        """
        self._folder_type = folder_type

    @property
    def folder_name(self):
        """
        Gets the folder_name of this SearchResult.
        Name of the parent folder object if this object is a sub folder, entity, or attribute.


        :return: The folder_name of this SearchResult.
        :rtype: str
        """
        return self._folder_name

    @folder_name.setter
    def folder_name(self, folder_name):
        """
        Sets the folder_name of this SearchResult.
        Name of the parent folder object if this object is a sub folder, entity, or attribute.


        :param folder_name: The folder_name of this SearchResult.
        :type: str
        """
        self._folder_name = folder_name

    @property
    def entitykey(self):
        """
        Gets the entitykey of this SearchResult.
        Unique key of the entity object if this object is an attribute.


        :return: The entitykey of this SearchResult.
        :rtype: str
        """
        return self._entitykey

    @entitykey.setter
    def entitykey(self, entitykey):
        """
        Sets the entitykey of this SearchResult.
        Unique key of the entity object if this object is an attribute.


        :param entitykey: The entitykey of this SearchResult.
        :type: str
        """
        self._entitykey = entitykey

    @property
    def entity_type(self):
        """
        Gets the entity_type of this SearchResult.
        Type name of the entity. For example, table, view, external table, file, or object.


        :return: The entity_type of this SearchResult.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this SearchResult.
        Type name of the entity. For example, table, view, external table, file, or object.


        :param entity_type: The entity_type of this SearchResult.
        :type: str
        """
        self._entity_type = entity_type

    @property
    def entity_name(self):
        """
        Gets the entity_name of this SearchResult.
        Name of the parent entity object if this object is an attribute.


        :return: The entity_name of this SearchResult.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this SearchResult.
        Name of the parent entity object if this object is an attribute.


        :param entity_name: The entity_name of this SearchResult.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def glossary_key(self):
        """
        Gets the glossary_key of this SearchResult.
        Unique id of the parent glossary.


        :return: The glossary_key of this SearchResult.
        :rtype: str
        """
        return self._glossary_key

    @glossary_key.setter
    def glossary_key(self, glossary_key):
        """
        Sets the glossary_key of this SearchResult.
        Unique id of the parent glossary.


        :param glossary_key: The glossary_key of this SearchResult.
        :type: str
        """
        self._glossary_key = glossary_key

    @property
    def glossary_name(self):
        """
        Gets the glossary_name of this SearchResult.
        Name of the parent glossary if this object is a term.


        :return: The glossary_name of this SearchResult.
        :rtype: str
        """
        return self._glossary_name

    @glossary_name.setter
    def glossary_name(self, glossary_name):
        """
        Sets the glossary_name of this SearchResult.
        Name of the parent glossary if this object is a term.


        :param glossary_name: The glossary_name of this SearchResult.
        :type: str
        """
        self._glossary_name = glossary_name

    @property
    def parent_term_key(self):
        """
        Gets the parent_term_key of this SearchResult.
        This terms parent term key. Will be null if the term has no parent term.


        :return: The parent_term_key of this SearchResult.
        :rtype: str
        """
        return self._parent_term_key

    @parent_term_key.setter
    def parent_term_key(self, parent_term_key):
        """
        Sets the parent_term_key of this SearchResult.
        This terms parent term key. Will be null if the term has no parent term.


        :param parent_term_key: The parent_term_key of this SearchResult.
        :type: str
        """
        self._parent_term_key = parent_term_key

    @property
    def parent_term_name(self):
        """
        Gets the parent_term_name of this SearchResult.
        Name of the parent term. Will be null if the term has no parent term.


        :return: The parent_term_name of this SearchResult.
        :rtype: str
        """
        return self._parent_term_name

    @parent_term_name.setter
    def parent_term_name(self, parent_term_name):
        """
        Sets the parent_term_name of this SearchResult.
        Name of the parent term. Will be null if the term has no parent term.


        :param parent_term_name: The parent_term_name of this SearchResult.
        :type: str
        """
        self._parent_term_name = parent_term_name

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this SearchResult.
        OCID of the user who created the resource.


        :return: The created_by_id of this SearchResult.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this SearchResult.
        OCID of the user who created the resource.


        :param created_by_id: The created_by_id of this SearchResult.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this SearchResult.
        OCID of the user who updated the resource.


        :return: The updated_by_id of this SearchResult.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this SearchResult.
        OCID of the user who updated the resource.


        :param updated_by_id: The updated_by_id of this SearchResult.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def path(self):
        """
        Gets the path of this SearchResult.
        Absolute path of this resource, which could be a term, folder, entity etc, usually resolvable to this resource through a namespace hierarchy.


        :return: The path of this SearchResult.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this SearchResult.
        Absolute path of this resource, which could be a term, folder, entity etc, usually resolvable to this resource through a namespace hierarchy.


        :param path: The path of this SearchResult.
        :type: str
        """
        self._path = path

    @property
    def business_name(self):
        """
        Gets the business_name of this SearchResult.
        Optional user friendly business name of the data object. If set, this supplements the harvested display name of the object.


        :return: The business_name of this SearchResult.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this SearchResult.
        Optional user friendly business name of the data object. If set, this supplements the harvested display name of the object.


        :param business_name: The business_name of this SearchResult.
        :type: str
        """
        self._business_name = business_name

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this SearchResult.
        The current state of the data object.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SearchResult.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SearchResult.
        The current state of the data object.


        :param lifecycle_state: The lifecycle_state of this SearchResult.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def attribute_type(self):
        """
        Gets the attribute_type of this SearchResult.
        Type name of the attribute. For example - complex, primitive, or array.


        :return: The attribute_type of this SearchResult.
        :rtype: str
        """
        return self._attribute_type

    @attribute_type.setter
    def attribute_type(self, attribute_type):
        """
        Sets the attribute_type of this SearchResult.
        Type name of the attribute. For example - complex, primitive, or array.


        :param attribute_type: The attribute_type of this SearchResult.
        :type: str
        """
        self._attribute_type = attribute_type

    @property
    def expression(self):
        """
        Gets the expression of this SearchResult.
        Expression for logical entities against which names of dataObjects will be matched.


        :return: The expression of this SearchResult.
        :rtype: str
        """
        return self._expression

    @expression.setter
    def expression(self, expression):
        """
        Sets the expression of this SearchResult.
        Expression for logical entities against which names of dataObjects will be matched.


        :param expression: The expression of this SearchResult.
        :type: str
        """
        self._expression = expression

    @property
    def custom_properties(self):
        """
        Gets the custom_properties of this SearchResult.
        Custom properties defined by users.


        :return: The custom_properties of this SearchResult.
        :rtype: list[oci.data_catalog.models.FacetedSearchCustomProperty]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """
        Sets the custom_properties of this SearchResult.
        Custom properties defined by users.


        :param custom_properties: The custom_properties of this SearchResult.
        :type: list[oci.data_catalog.models.FacetedSearchCustomProperty]
        """
        self._custom_properties = custom_properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeployPipelineArtifact(object):
    """
    Artifact used in the pipeline.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeployPipelineArtifact object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param deploy_artifact_id:
            The value to assign to the deploy_artifact_id property of this DeployPipelineArtifact.
        :type deploy_artifact_id: str

        :param display_name:
            The value to assign to the display_name property of this DeployPipelineArtifact.
        :type display_name: str

        :param deploy_pipeline_stages:
            The value to assign to the deploy_pipeline_stages property of this DeployPipelineArtifact.
        :type deploy_pipeline_stages: oci.devops.models.DeployPipelineStageCollection

        """
        self.swagger_types = {
            'deploy_artifact_id': 'str',
            'display_name': 'str',
            'deploy_pipeline_stages': 'DeployPipelineStageCollection'
        }

        self.attribute_map = {
            'deploy_artifact_id': 'deployArtifactId',
            'display_name': 'displayName',
            'deploy_pipeline_stages': 'deployPipelineStages'
        }

        self._deploy_artifact_id = None
        self._display_name = None
        self._deploy_pipeline_stages = None

    @property
    def deploy_artifact_id(self):
        """
        **[Required]** Gets the deploy_artifact_id of this DeployPipelineArtifact.
        The OCID of an artifact


        :return: The deploy_artifact_id of this DeployPipelineArtifact.
        :rtype: str
        """
        return self._deploy_artifact_id

    @deploy_artifact_id.setter
    def deploy_artifact_id(self, deploy_artifact_id):
        """
        Sets the deploy_artifact_id of this DeployPipelineArtifact.
        The OCID of an artifact


        :param deploy_artifact_id: The deploy_artifact_id of this DeployPipelineArtifact.
        :type: str
        """
        self._deploy_artifact_id = deploy_artifact_id

    @property
    def display_name(self):
        """
        Gets the display_name of this DeployPipelineArtifact.
        Display name of the artifact. Avoid entering confidential information.


        :return: The display_name of this DeployPipelineArtifact.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DeployPipelineArtifact.
        Display name of the artifact. Avoid entering confidential information.


        :param display_name: The display_name of this DeployPipelineArtifact.
        :type: str
        """
        self._display_name = display_name

    @property
    def deploy_pipeline_stages(self):
        """
        **[Required]** Gets the deploy_pipeline_stages of this DeployPipelineArtifact.

        :return: The deploy_pipeline_stages of this DeployPipelineArtifact.
        :rtype: oci.devops.models.DeployPipelineStageCollection
        """
        return self._deploy_pipeline_stages

    @deploy_pipeline_stages.setter
    def deploy_pipeline_stages(self, deploy_pipeline_stages):
        """
        Sets the deploy_pipeline_stages of this DeployPipelineArtifact.

        :param deploy_pipeline_stages: The deploy_pipeline_stages of this DeployPipelineArtifact.
        :type: oci.devops.models.DeployPipelineStageCollection
        """
        self._deploy_pipeline_stages = deploy_pipeline_stages

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryAggregation(object):
    """
    Query results.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new QueryAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_count:
            The value to assign to the total_count property of this QueryAggregation.
        :type total_count: int

        :param total_matched_count:
            The value to assign to the total_matched_count property of this QueryAggregation.
        :type total_matched_count: int

        :param are_partial_results:
            The value to assign to the are_partial_results property of this QueryAggregation.
        :type are_partial_results: bool

        :param partial_result_reason:
            The value to assign to the partial_result_reason property of this QueryAggregation.
        :type partial_result_reason: str

        :param columns:
            The value to assign to the columns property of this QueryAggregation.
        :type columns: list[oci.log_analytics.models.AbstractColumn]

        :param fields:
            The value to assign to the fields property of this QueryAggregation.
        :type fields: list[oci.log_analytics.models.AbstractColumn]

        :param items:
            The value to assign to the items property of this QueryAggregation.
        :type items: list[dict(str, object)]

        :param query_execution_time_in_ms:
            The value to assign to the query_execution_time_in_ms property of this QueryAggregation.
        :type query_execution_time_in_ms: int

        :param percent_complete:
            The value to assign to the percent_complete property of this QueryAggregation.
        :type percent_complete: int

        """
        self.swagger_types = {
            'total_count': 'int',
            'total_matched_count': 'int',
            'are_partial_results': 'bool',
            'partial_result_reason': 'str',
            'columns': 'list[AbstractColumn]',
            'fields': 'list[AbstractColumn]',
            'items': 'list[dict(str, object)]',
            'query_execution_time_in_ms': 'int',
            'percent_complete': 'int'
        }

        self.attribute_map = {
            'total_count': 'totalCount',
            'total_matched_count': 'totalMatchedCount',
            'are_partial_results': 'arePartialResults',
            'partial_result_reason': 'partialResultReason',
            'columns': 'columns',
            'fields': 'fields',
            'items': 'items',
            'query_execution_time_in_ms': 'queryExecutionTimeInMs',
            'percent_complete': 'percentComplete'
        }

        self._total_count = None
        self._total_matched_count = None
        self._are_partial_results = None
        self._partial_result_reason = None
        self._columns = None
        self._fields = None
        self._items = None
        self._query_execution_time_in_ms = None
        self._percent_complete = None

    @property
    def total_count(self):
        """
        Gets the total_count of this QueryAggregation.
        Number of rows query retrieved. Up to maxTotalCount limit.


        :return: The total_count of this QueryAggregation.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """
        Sets the total_count of this QueryAggregation.
        Number of rows query retrieved. Up to maxTotalCount limit.


        :param total_count: The total_count of this QueryAggregation.
        :type: int
        """
        self._total_count = total_count

    @property
    def total_matched_count(self):
        """
        Gets the total_matched_count of this QueryAggregation.
        Number of rows matched by query.


        :return: The total_matched_count of this QueryAggregation.
        :rtype: int
        """
        return self._total_matched_count

    @total_matched_count.setter
    def total_matched_count(self, total_matched_count):
        """
        Sets the total_matched_count of this QueryAggregation.
        Number of rows matched by query.


        :param total_matched_count: The total_matched_count of this QueryAggregation.
        :type: int
        """
        self._total_matched_count = total_matched_count

    @property
    def are_partial_results(self):
        """
        Gets the are_partial_results of this QueryAggregation.
        True if query did not complete processing all data.


        :return: The are_partial_results of this QueryAggregation.
        :rtype: bool
        """
        return self._are_partial_results

    @are_partial_results.setter
    def are_partial_results(self, are_partial_results):
        """
        Sets the are_partial_results of this QueryAggregation.
        True if query did not complete processing all data.


        :param are_partial_results: The are_partial_results of this QueryAggregation.
        :type: bool
        """
        self._are_partial_results = are_partial_results

    @property
    def partial_result_reason(self):
        """
        Gets the partial_result_reason of this QueryAggregation.
        Explanation of why results may be partial. Only set if arePartialResults is true.


        :return: The partial_result_reason of this QueryAggregation.
        :rtype: str
        """
        return self._partial_result_reason

    @partial_result_reason.setter
    def partial_result_reason(self, partial_result_reason):
        """
        Sets the partial_result_reason of this QueryAggregation.
        Explanation of why results may be partial. Only set if arePartialResults is true.


        :param partial_result_reason: The partial_result_reason of this QueryAggregation.
        :type: str
        """
        self._partial_result_reason = partial_result_reason

    @property
    def columns(self):
        """
        Gets the columns of this QueryAggregation.
        Query result columns


        :return: The columns of this QueryAggregation.
        :rtype: list[oci.log_analytics.models.AbstractColumn]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this QueryAggregation.
        Query result columns


        :param columns: The columns of this QueryAggregation.
        :type: list[oci.log_analytics.models.AbstractColumn]
        """
        self._columns = columns

    @property
    def fields(self):
        """
        Gets the fields of this QueryAggregation.
        Query result fields


        :return: The fields of this QueryAggregation.
        :rtype: list[oci.log_analytics.models.AbstractColumn]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this QueryAggregation.
        Query result fields


        :param fields: The fields of this QueryAggregation.
        :type: list[oci.log_analytics.models.AbstractColumn]
        """
        self._fields = fields

    @property
    def items(self):
        """
        Gets the items of this QueryAggregation.
        Query result data


        :return: The items of this QueryAggregation.
        :rtype: list[dict(str, object)]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this QueryAggregation.
        Query result data


        :param items: The items of this QueryAggregation.
        :type: list[dict(str, object)]
        """
        self._items = items

    @property
    def query_execution_time_in_ms(self):
        """
        Gets the query_execution_time_in_ms of this QueryAggregation.
        Time ellapsed executing query in milli-seconds.


        :return: The query_execution_time_in_ms of this QueryAggregation.
        :rtype: int
        """
        return self._query_execution_time_in_ms

    @query_execution_time_in_ms.setter
    def query_execution_time_in_ms(self, query_execution_time_in_ms):
        """
        Sets the query_execution_time_in_ms of this QueryAggregation.
        Time ellapsed executing query in milli-seconds.


        :param query_execution_time_in_ms: The query_execution_time_in_ms of this QueryAggregation.
        :type: int
        """
        self._query_execution_time_in_ms = query_execution_time_in_ms

    @property
    def percent_complete(self):
        """
        **[Required]** Gets the percent_complete of this QueryAggregation.
        Percentage progress completion of the query.


        :return: The percent_complete of this QueryAggregation.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this QueryAggregation.
        Percentage progress completion of the query.


        :param percent_complete: The percent_complete of this QueryAggregation.
        :type: int
        """
        self._percent_complete = percent_complete

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
